Crate hdf5_metno_types

Crate hdf5_metno_types 

Types that can be stored and retrieved from a HDF5 dataset

Crate features:

  • h5-alloc: Use the hdf5 allocator for varlen types and dynamic values. This is necessary on platforms which uses different allocators in different libraries (e.g. dynamic libraries on windows), or if hdf5-c is compiled with the MEMCHECKER option. This option is forced on in the case of using a windows DLL.

Re-exports

pub use self::dyn_value::DynValue;
pub use self::dyn_value::OwnedDynValue;
pub use self::references::Reference;

Modules

dyn_value
Dynamically-typed values.
references
Types for references.

Structs

CompoundField
A descriptor for a compound datatype field.
CompoundType
A descriptor for a compound datatype.
EnumMember
A descriptor for an enumeration datatype member.
EnumType
A descriptor for an enumeration datatype.
FixedAscii
A fixed-length ASCII string.
FixedUnicode
A fixed-length UTF-8 string.
VarLenArray
A variable-length array.
VarLenAscii
A variable-length ASCII string.
VarLenUnicode
A variable-length UTF-8 string.

Enums

FloatSize
A valid floating-point number size.
IntSize
A valid integer size.
StringError
Errors that can occur when attempting to interpret a byte sequence as a string.
TypeDescriptor
A descriptor for an HDF5 datatype.

Constants

USING_H5_ALLOCATOR
Whether this crate is using the HDF5 library for allocations instead of libc.

Traits

H5Type
A type that can be represented as an HDF5 datatype.