Types that can be stored and retrieved from a HDF5 dataset
Crate features:
h5-alloc: Use thehdf5allocator for varlen types and dynamic values. This is necessary on platforms which uses different allocators in different libraries (e.g. dynamic libraries on windows), or ifhdf5-cis compiled with the MEMCHECKER option. This option is forced on in the case of using awindowsDLL.
Re-exports
pub use self::dyn_value::DynValue;pub use self::dyn_value::OwnedDynValue;pub use self::references::Reference;
Modules
- dyn_
value - Dynamically-typed values.
- references
- Types for references.
Structs
- Compound
Field - A descriptor for a compound datatype field.
- Compound
Type - A descriptor for a compound datatype.
- Enum
Member - A descriptor for an enumeration datatype member.
- Enum
Type - A descriptor for an enumeration datatype.
- Fixed
Ascii - A fixed-length ASCII string.
- Fixed
Unicode - A fixed-length UTF-8 string.
- VarLen
Array - A variable-length array.
- VarLen
Ascii - A variable-length ASCII string.
- VarLen
Unicode - A variable-length UTF-8 string.
Enums
- Float
Size - A valid floating-point number size.
- IntSize
- A valid integer size.
- String
Error - Errors that can occur when attempting to interpret a byte sequence as a string.
- Type
Descriptor - A descriptor for an HDF5 datatype.
Constants
- USING_
H5_ ALLOCATOR - Whether this crate is using the HDF5 library for allocations instead of
libc.
Traits
- H5Type
- A type that can be represented as an HDF5 datatype.